@@ -23,7 +23,6 @@ Examples:
   pyraider autofix
   pyraider autofix -s high
   pyraider updatedb
-  pyraider updatedb -d
 
 Options:
   -h, --help
@@ -45,7 +44,7 @@ logo = """
          __/ |
         |___/
 
-by RaiderSource version 1.0.8
+by RaiderSource version 1.0.13
 """
 
 
@@ -60,7 +59,7 @@ def find_file(name, path):
 
 def main():
     print(logo)
-    arguments = docopt(__doc__, version='1.0.8')
+    arguments = docopt(__doc__, version='1.0.13')
     if arguments.get('check'):
         if arguments.get('high'):
             if arguments.get('<filename>') and not arguments.get('<exportFileName>') and not arguments.get('<format>') and not arguments.get('-d'):
@@ -303,16 +302,10 @@ def main():
             except Exception as e:
                 exit(1)
     if arguments.get('updatedb'):
-        if arguments.get('-d'):
-            try:
-                update_db(deep_scan=True)
-            except Exception as e:
-                exit(1)
-        else:
-            try:
-                update_db()
-            except Exception as e:
-                exit(1)
+        try:
+            update_db()
+        except Exception as e:
+            exit(1)
 
 
 if __name__ == "__main__":
